@@ -52,10 +52,6 @@ G_BEGIN_DECLS
 
 #define TRACKER_DB_INTERFACE_ERROR          (tracker_db_interface_error_quark ())
 
-typedef void (*TrackerBusyCallback)      (const gchar *status,
-                                          gdouble      progress,
-                                          gpointer     user_data);
-
 typedef enum {
 	TRACKER_DB_QUERY_ERROR,
 	TRACKER_DB_INTERRUPTED,
@@ -67,7 +63,6 @@ typedef enum {
 
 typedef enum {
 	TRACKER_DB_STATEMENT_CACHE_TYPE_SELECT,
-	TRACKER_DB_STATEMENT_CACHE_TYPE_UPDATE,
 	TRACKER_DB_STATEMENT_CACHE_TYPE_NONE
 } TrackerDBStatementCacheType;
 
@@ -99,9 +94,7 @@ void                    tracker_db_interface_set_max_stmt_cache_size (TrackerDBI
 
 /* User data functions, mainly to attach the data manager */
 void                    tracker_db_interface_set_user_data           (TrackerDBInterface         *interface,
-                                                                      gpointer                    user_data,
-	                                                              GDestroyNotify              destroy_notify);
-gpointer                tracker_db_interface_get_user_data           (TrackerDBInterface         *interface);
+                                                                      GObject                    *user_data);
 
 /* Functions to create queries/procedures */
 TrackerDBStatement *    tracker_db_interface_create_statement        (TrackerDBInterface           *db_interface,
@@ -174,26 +167,9 @@ void tracker_db_statement_mru_insert (TrackerDBStatementMru *mru,
 void tracker_db_statement_mru_update (TrackerDBStatementMru *mru,
                                       TrackerDBStatement    *stmt);
 
-/* Functions to deal with a cursor */
-void                    tracker_db_cursor_rewind                     (TrackerDBCursor            *cursor);
-gboolean                tracker_db_cursor_iter_next                  (TrackerDBCursor            *cursor,
-                                                                      GCancellable               *cancellable,
-                                                                      GError                    **error);
-guint                   tracker_db_cursor_get_n_columns              (TrackerDBCursor            *cursor);
-const gchar*            tracker_db_cursor_get_variable_name          (TrackerDBCursor            *cursor,
-                                                                      guint                       column);
-TrackerSparqlValueType  tracker_db_cursor_get_value_type             (TrackerDBCursor            *cursor,
-                                                                      guint                       column);
-void                    tracker_db_cursor_get_value                  (TrackerDBCursor            *cursor,
-                                                                      guint                       column,
-                                                                      GValue                     *value);
-const gchar*            tracker_db_cursor_get_string                 (TrackerDBCursor            *cursor,
-                                                                      guint                       column,
-                                                                      glong                      *length);
-gint64                  tracker_db_cursor_get_int                    (TrackerDBCursor            *cursor,
-                                                                      guint                       column);
-gdouble                 tracker_db_cursor_get_double                 (TrackerDBCursor            *cursor,
-                                                                      guint                       column);
+void tracker_db_cursor_get_value (TrackerDBCursor            *cursor,
+                                  guint                       column,
+                                  GValue                     *value);
 
 G_END_DECLS
 
