@@ -468,7 +468,6 @@ tracker_db_manager_check_integrity (TrackerDBManager  *db_manager,
 TrackerDBManager *
 tracker_db_manager_new (TrackerDBManagerFlags   flags,
                         GFile                  *cache_location,
-                        gboolean                shared_cache,
                         guint                   select_cache_size,
                         GObject                *iface_data,
                         GError                **error)
@@ -570,12 +569,6 @@ tracker_db_manager_new (TrackerDBManagerFlags   flags,
 		db_manager->flags = (db_manager->flags & ~(FTS_FLAGS)) | fts_flags;
 	}
 
-	/* Set general database options */
-	if (shared_cache) {
-		TRACKER_NOTE (SQLITE, g_message ("Enabling database shared cache"));
-		tracker_db_interface_sqlite_enable_shared_cache ();
-	}
-
 	if (need_to_create) {
 		db_manager->first_time = TRUE;
 
@@ -653,8 +646,6 @@ tracker_db_manager_create_db_interface (TrackerDBManager  *db_manager,
 
 	if (readonly)
 		flags |= TRACKER_DB_INTERFACE_READONLY;
-	if (db_manager->flags & TRACKER_DB_MANAGER_ENABLE_MUTEXES)
-		flags |= TRACKER_DB_INTERFACE_USE_MUTEX;
 	if (db_manager->flags & TRACKER_DB_MANAGER_IN_MEMORY)
 		flags |= TRACKER_DB_INTERFACE_IN_MEMORY;
 
