@@ -47,7 +47,4 @@ gboolean tracker_sparql_execute_update (TrackerSparql  *sparql,
                                         GVariant      **bnodes_variant,
                                         GError        **error);
 
-GBytes * tracker_sparql_make_langstring (const gchar *str,
-                                         const gchar *langtag);
-
 #endif /* __TRACKER_SPARQL_H__ */
