@@ -28,14 +28,20 @@
  *   ([http://www.w3.org/ns/formats/Turtle](http://www.w3.org/ns/formats/Turtle))
  * @TRACKER_RDF_FORMAT_TRIG: Trig format
  *   ([http://www.w3.org/ns/formats/Trig](http://www.w3.org/ns/formats/Trig))
- * @TRACKER_N_RDF_FORMATS: The total number of RDF formats
+ * @TRACKER_RDF_FORMAT_JSON_LD: JSON-LD format
+ *   ([http://www.w3.org/ns/formats/JSON-LD](http://www.w3.org/ns/formats/JSON-LD)).
+ *   This value was added in version 3.5.
+ * @TRACKER_RDF_FORMAT_LAST: The total number of RDF formats
  *
  * Describes a RDF format to be used in data exchange.
  */
 typedef enum {
 	TRACKER_RDF_FORMAT_TURTLE,
 	TRACKER_RDF_FORMAT_TRIG,
-	TRACKER_N_RDF_FORMATS
+	TRACKER_RDF_FORMAT_JSON_LD,
+	TRACKER_RDF_FORMAT_LAST
 } TrackerRdfFormat;
 
+#define TRACKER_N_RDF_FORMATS TRACKER_RDF_FORMAT_LAST
+
 #endif /* TRACKER_ENUMS_H */
