@@ -37,7 +37,8 @@ _tracker_notifier_event_cache_push_event (TrackerNotifierEventCache *cache,
                                           gint64                     id,
                                           TrackerNotifierEventType   event_type);
 
-void _tracker_notifier_event_cache_flush_events (TrackerNotifierEventCache *cache);
+void _tracker_notifier_event_cache_flush_events (TrackerNotifier           *notifier,
+                                                 TrackerNotifierEventCache *cache);
 
 const gchar * tracker_notifier_event_cache_get_graph (TrackerNotifierEventCache *cache);
 
