@@ -27,15 +27,11 @@
 #include <gio/gio.h>
 #include <libtracker-sparql/tracker-version.h>
 
+G_BEGIN_DECLS
+
 #define TRACKER_TYPE_NOTIFIER (tracker_notifier_get_type ())
 #define TRACKER_TYPE_NOTIFIER_EVENT (tracker_notifier_event_get_type ())
 
-/**
- * TrackerNotifier:
- *
- * The <structname>TrackerNotifier</structname> object allows subscribing
- * to changes in the stored data.
- */
 TRACKER_AVAILABLE_IN_ALL
 G_DECLARE_DERIVABLE_TYPE (TrackerNotifier, tracker_notifier, TRACKER, NOTIFIER, GObject)
 
@@ -82,4 +78,6 @@ gint64        tracker_notifier_event_get_id         (TrackerNotifierEvent *event
 TRACKER_AVAILABLE_IN_ALL
 const gchar * tracker_notifier_event_get_urn        (TrackerNotifierEvent *event);
 
+G_END_DECLS
+
 #endif /* __TRACKER_NOTIFIER_H__ */
