@@ -80,6 +80,10 @@ struct _TrackerSparqlConnectionClass
                                                       const gchar              *sparql,
                                                       GCancellable             *cancellable,
                                                       GError                  **error);
+        TrackerSparqlStatement * (* update_statement) (TrackerSparqlConnection  *connection,
+                                                       const gchar              *sparql,
+                                                       GCancellable             *cancellable,
+                                                       GError                  **error);
 	TrackerNotifier * (* create_notifier) (TrackerSparqlConnection *connection);
 
 	void (* close) (TrackerSparqlConnection *connection);
@@ -147,9 +151,10 @@ struct _TrackerSparqlCursorClass
 	                                           gint                 column);
         const gchar* (* get_variable_name) (TrackerSparqlCursor *cursor,
                                             gint                 column);
-	const gchar* (* get_string) (TrackerSparqlCursor *cursor,
-	                             gint                 column,
-	                             glong               *length);
+	const gchar* (* get_string) (TrackerSparqlCursor  *cursor,
+	                             gint                  column,
+	                             const gchar         **langtag,
+	                             glong                *length);
         gboolean (* next) (TrackerSparqlCursor  *cursor,
                            GCancellable         *cancellable,
                            GError              **error);
@@ -191,20 +196,8 @@ struct _TrackerEndpointDBus {
 
 typedef struct _TrackerEndpointDBusClass TrackerEndpointDBusClass;
 
-typedef enum {
-	TRACKER_OPERATION_TYPE_SELECT,
-	TRACKER_OPERATION_TYPE_UPDATE,
-} TrackerOperationType;
-
 struct _TrackerEndpointDBusClass {
 	struct _TrackerEndpointClass parent_class;
-
-	gboolean (* forbid_operation) (TrackerEndpointDBus   *endpoint_dbus,
-	                               GDBusMethodInvocation *invocation,
-	                               TrackerOperationType   operation_type);
-	gboolean (* filter_graph) (TrackerEndpointDBus *endpoint_dbus,
-	                           const gchar         *graph_name);
-	gchar * (* add_prologue) (TrackerEndpointDBus *endpoint_dbus);
 };
 
 typedef struct _TrackerEndpointHttpClass TrackerEndpointHttpClass;
@@ -237,6 +230,10 @@ struct _TrackerSparqlStatementClass
         void (* bind_datetime) (TrackerSparqlStatement *stmt,
                                 const gchar            *name,
                                 GDateTime              *value);
+	void (* bind_langstring) (TrackerSparqlStatement *stmt,
+	                          const gchar            *name,
+	                          const gchar            *value,
+	                          const gchar            *langtag);
 
         TrackerSparqlCursor * (* execute) (TrackerSparqlStatement  *stmt,
                                            GCancellable            *cancellable,
@@ -259,6 +256,17 @@ struct _TrackerSparqlStatementClass
         GInputStream * (* serialize_finish) (TrackerSparqlStatement  *stmt,
                                              GAsyncResult            *res,
                                              GError                 **error);
+
+        gboolean (* update) (TrackerSparqlStatement  *stmt,
+                             GCancellable            *cancellable,
+                             GError                 **error);
+        void (* update_async) (TrackerSparqlStatement *stmt,
+                               GCancellable           *cancellable,
+                               GAsyncReadyCallback     callback,
+                               gpointer                user_data);
+        gboolean (* update_finish) (TrackerSparqlStatement  *stmt,
+                                    GAsyncResult            *res,
+                                    GError                 **error);
 };
 
 struct _TrackerNotifierClass {
@@ -276,6 +284,18 @@ struct _TrackerBatchClass {
 	void (* add_resource) (TrackerBatch    *batch,
 			       const gchar     *graph,
 			       TrackerResource *resource);
+	void (* add_statement) (TrackerBatch           *batch,
+	                        TrackerSparqlStatement *stmt,
+	                        guint                   n_values,
+	                        const gchar            *variable_names[],
+	                        const GValue            values[]);
+	void (* add_rdf) (TrackerBatch            *batch,
+	                  TrackerDeserializeFlags  flags,
+	                  TrackerRdfFormat         format,
+	                  const gchar             *default_graph,
+	                  GInputStream            *stream);
+	void (* add_dbus_fd) (TrackerBatch *batch,
+	                      GInputStream *istream);
 	gboolean (* execute) (TrackerBatch  *batch,
 			      GCancellable  *cancellable,
 			      GError       **error);
@@ -332,4 +352,21 @@ gboolean tracker_resource_iterator_next (TrackerResourceIterator  *iter,
 const gchar * tracker_resource_get_identifier_internal (TrackerResource *resource);
 gboolean tracker_resource_is_blank_node (TrackerResource *resource);
 
+void tracker_endpoint_rewrite_query (TrackerEndpoint  *endpoint,
+                                     gchar           **query);
+
+gboolean tracker_endpoint_is_graph_filtered (TrackerEndpoint *endpoint,
+                                             const gchar     *graph);
+
+TrackerSparqlStatement * tracker_endpoint_cache_select_sparql (TrackerEndpoint  *endpoint,
+                                                               const gchar      *sparql,
+                                                               GCancellable     *cancellable,
+                                                               GError          **error);
+
+void tracker_batch_add_dbus_fd (TrackerBatch *batch,
+                                GInputStream *istream);
+
+GBytes * tracker_sparql_make_langstring (const gchar *str,
+                                         const gchar *langtag);
+
 #endif /* __TRACKER_PRIVATE_H__ */
