@@ -110,5 +110,27 @@ tracker_sparql_get_uuid_urn (void)
 GFile *
 tracker_sparql_get_ontology_nepomuk (void)
 {
-	return g_file_new_for_path (SHAREDIR "/tracker3/ontologies/nepomuk");
+	return g_file_new_for_uri ("resource://org/freedesktop/tracker/nepomuk");
+}
+
+GBytes *
+tracker_sparql_make_langstring (const gchar *str,
+                                const gchar *langtag)
+{
+	GString *langstr;
+	GBytes *bytes;
+	gsize len;
+
+	langstr = g_string_new (str);
+
+	if (langtag) {
+		g_string_append_c (langstr, '\0');
+		g_string_append_printf (langstr, "%s", langtag);
+	}
+
+	/* Account for trailing \0 */
+	len = langstr->len + 1;
+	bytes = g_bytes_new_take (g_string_free (langstr, FALSE), len);
+
+	return bytes;
 }
