@@ -900,6 +900,7 @@ tree_get (TrackerSparqlConnection *connection,
 		            error->message);
 		g_error_free (error);
 		g_object_unref (connection);
+		g_free (class_lookup_longhand);
 
 		return EXIT_FAILURE;
 	}
@@ -956,9 +957,7 @@ tree_get (TrackerSparqlConnection *connection,
 				g_hash_table_unref (filter_parents);
 			}
 
-			if (cursor) {
-				g_object_unref (cursor);
-			}
+			g_object_unref (cursor);
 
 			return EXIT_FAILURE;
 		}
@@ -970,9 +969,7 @@ tree_get (TrackerSparqlConnection *connection,
 			tree_add_property (root, class, property);
 		}
 
-		if (properties) {
-			g_object_unref (properties);
-		}
+		g_object_unref (properties);
 	}
 
 	g_free (class_lookup_longhand);
@@ -984,10 +981,7 @@ tree_get (TrackerSparqlConnection *connection,
 		g_hash_table_unref (filter_parents);
 	}
 
-	if (cursor) {
-		g_object_unref (cursor);
-	}
-
+	g_object_unref (cursor);
 	tree_free (root);
 
 	return EXIT_SUCCESS;
