@@ -72,13 +72,15 @@ check_result (GInputStream *istream,
 	gchar *shell;
 	gchar *diff;
 	gchar output[8096] = { 0 };
+	gboolean retval;
 
 	g_input_stream_read_all (istream,
 	                         output, sizeof (output),
 	                         NULL, NULL, &error);
 	g_assert_no_error (error);
 
-	g_file_get_contents (results_filename, &results, NULL, &nerror);
+	retval = g_file_get_contents (results_filename, &results, NULL, &nerror);
+	g_assert_true (retval);
 	g_assert_no_error (nerror);
 	g_clear_error (&nerror);
 
@@ -150,12 +152,14 @@ serialize (TestFixture   *test_fixture,
 	GError *error = NULL;
 	gchar *path, *query;
 	TestInfo *test_info = test_fixture->test;
+	gboolean retval;
 
 	test_fixture->loop = g_main_loop_new (NULL, FALSE);
 
 	path = g_build_filename (TOP_SRCDIR, "tests", "libtracker-sparql",
 	                         test_info->query_file, NULL);
-	g_file_get_contents (path, &query, NULL, &error);
+	retval = g_file_get_contents (path, &query, NULL, &error);
+	g_assert_true (retval);
 	g_assert_no_error (error);
 	g_free (path);
 
@@ -229,17 +233,17 @@ populate_data (TrackerSparqlConnection *conn)
 TrackerSparqlConnection *
 create_local_connection (GError **error)
 {
-        TrackerSparqlConnection *conn;
-        GFile *ontology;
+	TrackerSparqlConnection *conn;
+	GFile *ontology;
 
-        ontology = g_file_new_for_path (TEST_ONTOLOGIES_DIR);
+	ontology = tracker_sparql_get_ontology_nepomuk ();
 
-        conn = tracker_sparql_connection_new (0, NULL, ontology, NULL, error);
-        g_object_unref (ontology);
+	conn = tracker_sparql_connection_new (0, NULL, ontology, NULL, error);
+	g_object_unref (ontology);
 
-        populate_data (conn);
+	populate_data (conn);
 
-        return conn;
+	return conn;
 }
 
 static gpointer
